enumTablePartitionStrategy
enum TablePartitionStrategy: string
How a table's rows are divided between its partitions.
Cases
case Range = 'range'case List = 'list'case Hash = 'hash'Test cases 23
Test cases that cover or call this symbol, from the coverage report and from the analyzed test sources.
Dedicated tests 1
Other tests reaching this symbol 22
PgSqlPartitionReflectorTest::testReflectsKeysAndParentRelationsFromCatalogcallsTablePartitionKeyTest::testStoresStrategyAndExpressionscallsPgSqlSchemaParserTest::testPartitionClauseDoesNotBecomePartOfTableBodycallsPartitionKeysTest::testReflectIgnoresMalformedRowsAndKeepsThePartitionExpressioncallsTableDefinitionTest::testCandidateKeysWithPartitionKeyCandidateKeysPartitionMetadataCopiesPreserveOtherSchemaStatecallsTableDefinitionTest::testWithPartitionKeyAnswersATableDividedByThatKeycallsTableMutationResolverTest::testResolvePartitionInheritsItsParentDefinitioncallsPgSqlMutationResolverTest::testSubpartitionDdlStoresItsOwnPartitionKeycallsBoundPredicateTest::testListPredicatecallsBoundPredicateTest::testRangePredicatecallsPgSqlPartitionParserTest::testIgnoresNestedPartitionKeywordsWhenFindingTopLevelClausescallsPgSqlPartitionParserTest::testListPredicatesDistinguishValuesNullAndWhitespacecallsPgSqlPartitionParserTest::testParentTableRejectsMalformedPartitionClausescallsPgSqlPartitionParserTest::testParseKeyParsesRangePartitionKeyAndBoundscallsPgSqlPartitionParserTest::testParseRelationParsesListPartitionIncludingNullcallsPgSqlPartitionParserTest::testParsesAllKeyStrategiescallsPgSqlPartitionParserTest::testParsesDefaultPartitioncallsPgSqlPartitionParserTest::testParsesFiniteMultiColumnRangeAsRowComparisoncallsPgSqlPartitionParserTest::testParsesUnboundedRangecallsPgSqlPartitionParserTest::testRejectsHashAndMixedUnboundedRangeInsteadOfGuessingcallsPgSqlPartitionParserTest::testRejectsMalformedBoundsIndependentlycallsPgSqlPartitionParserTest::testSkipsIncompleteKeywordPairBeforeThePartitionClausecalls
Relations
Constant reads 6
- class-const ZtdQuery\Platform\Postgres\Sql\Partition\PgSqlPartitionParser::parseKey() packages/ztd-query-postgres/src/Sql/Partition/PgSqlPartitionParser.php:36
- class-const ZtdQuery\Platform\Postgres\Sql\Partition\PgSqlPartitionParser::parseKey() packages/ztd-query-postgres/src/Sql/Partition/PgSqlPartitionParser.php:37
- class-const ZtdQuery\Platform\Postgres\Sql\Partition\PgSqlPartitionParser::parseKey() packages/ztd-query-postgres/src/Sql/Partition/PgSqlPartitionParser.php:38
- class-const ZtdQuery\Platform\Postgres\Sql\Partition\PgSqlPartitionParser::parseRelation() packages/ztd-query-postgres/src/Sql/Partition/PgSqlPartitionParser.php:102
- class-const ZtdQuery\Platform\Postgres\Sql\Partition\PgSqlPartitionParser::parseRelation() packages/ztd-query-postgres/src/Sql/Partition/PgSqlPartitionParser.php:103
- class-const ZtdQuery\Platform\Postgres\Sql\Partition\PgSqlPartitionParser::parseRelation() packages/ztd-query-postgres/src/Sql/Partition/PgSqlPartitionParser.php:104